// -*- C++ -*-
/**
 * \file QSendtoDialog.h
 * This file is part of LyX, the document processor.
 * Licence details can be found in the file COPYING.
 *
 * \author Jrgen Spitzmller
 *
 * Full author contact details are available in file CREDITS.
 */

#ifndef QSENDTODIALOG_H
#define QSENDTODIALOG_H

#include "ui/QSendtoDialogBase.h"

namespace lyx {
namespace frontend {

class QSendto;

class QSendtoDialog : public QSendtoDialogBase {
	Q_OBJECT
public:
	QSendtoDialog(QSendto * form);
protected slots:
	virtual void changed_adaptor();
	virtual void slotFormatHighlighted(const QString&) {}
	virtual void slotFormatSelected(const QString&) {}
protected:
	virtual void closeEvent(QCloseEvent * e);
private:
	QSendto * form_;
};

} // namespace frontend
} // namespace lyx

#endif // QSENDTODIALOG_H
